==> qmmp_0.6.6.orig.tar.gz: qmmp-0.6.6/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="93"/>
        <source>FFmpeg Plugin</source>
        <translation>תוספת FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="95"/>
        <source>FFmpeg Formats</source>
        <translation>פורמטים של FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="257"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>אודות תוספת שמע FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="259"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>תוספת שמע FFmpeg ‫Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="260"/>
        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
        <translation>הודרה כנגד libavformat-%1.%2.%3 וכנגד libavcodec-%4.%5.%6</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="267"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov ‫&lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="52"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="99"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="53"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="100"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="53"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="100"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="54"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="101"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="54"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="101"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="117"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="117"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="67"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="118"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>הגדרות תוספת FFmpeg</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>פורמטים</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>שמע אמיתי</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation>מקוצר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation>שמע Matroska ‫(Dolby TrueHD נטול אובדן)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="158"/>
        <source>FFmpeg Plugin</source>
        <translation>תוסף FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="160"/>
        <source>FFmpeg Formats</source>
        <translation>פורמטים של FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="267"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>אודות תוסף שמע FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="268"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>תוסף שמע FFmpeg של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="269"/>
        <source>Compiled against:</source>
        <translation>הודר כנגד:</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="282"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="50"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="51"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="51"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="52"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="52"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="73"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>הגדרות תוסף FFmpeg</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>פורמטים</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation>Windows Media Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation>Monkey&apos;s Audio (APE)‎</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>שמע אמיתי</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation>ADTS AAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation>MP3 (MPEG audio layer 3)‎</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation>MPEG-4 AAC/ALAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation>RealAudio 1.0/2.0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation>מקוצר</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation>AC3/EAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation>ליבת DTS/DTS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation>שמע Matroska ‏(Dolby TrueHD נטול אובדן)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation>VQF</translation>
    </message>
</context>
</TS>
